package com.cmeeting.job;

import cn.chatbot.openai.completion.chat.ChatCompletionRequest;
import cn.chatbot.openai.completion.chat.ChatMessage;
import cn.chatbot.openai.completion.chat.ChatMessageRole;
import cn.chatbot.openai.completion.chat.Message;
import cn.chatbot.openai.service.LLMService;
import com.cmeeting.email.EmailSender;
import com.tencentcloudapi.wemeet.Client;
import com.tencentcloudapi.wemeet.core.authenticator.AuthenticatorBuilder;
import com.tencentcloudapi.wemeet.core.authenticator.JWTAuthenticator;
import com.tencentcloudapi.wemeet.core.exception.ClientException;
import com.tencentcloudapi.wemeet.core.exception.ServiceException;
import com.tencentcloudapi.wemeet.service.records.api.RecordsApi;
import com.tencentcloudapi.wemeet.service.records.model.*;
import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.Response;
import org.apache.poi.xwpf.extractor.XWPFWordExtractor;
import org.apache.poi.xwpf.usermodel.XWPFDocument;
import org.apache.poi.xwpf.usermodel.XWPFParagraph;
import org.apache.poi.xwpf.usermodel.XWPFRun;
import org.commonmark.node.*;
import org.commonmark.parser.Parser;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import java.io.*;
import java.math.BigInteger;
import java.nio.charset.Charset;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.security.SecureRandom;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.time.ZoneId;
import java.time.format.DateTimeFormatter;
import java.util.*;

@Component
public class CmeetingJob {
    private static final Logger logger = LoggerFactory.getLogger(CmeetingJob.class);
    private static final DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");
    private static final Set<String> processedMeetingIds = Collections.synchronizedSet(new HashSet<>());

    @Scheduled(fixedRate = 5 * 60 * 1000)
    public void execute() {
        // 定义时间格式化器
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");

        // 获取当前日期
        LocalDate today = LocalDate.now();
        // 获取今天凌晨的时间点
        LocalDateTime todayStart = today.atStartOfDay();
        // 获取明天凌晨的时间点
        LocalDateTime tomorrowStart = today.plusDays(1).atStartOfDay();

        // 转换为 Unix 时间戳（秒）并转为字符串
        String todayStartTimestamp = String.valueOf(todayStart.atZone(ZoneId.systemDefault()).toEpochSecond());
        String tomorrowStartTimestamp = String.valueOf(tomorrowStart.atZone(ZoneId.systemDefault()).toEpochSecond());
        //日志记录
        logger.info("今天凌晨: " + todayStart.format(formatter) + " | Unix 时间戳: " + todayStartTimestamp);
        logger.info("明天凌晨: " + tomorrowStart.format(formatter) + " | Unix 时间戳: " + tomorrowStartTimestamp);
        logger.info("----------------------------------");

        dojob(todayStartTimestamp, tomorrowStartTimestamp);
    }

    public static void dojob(String startTime, String endTime) {
        Client client = new Client.Builder()
                .withAppId("210468336")
                .withSdkId("28790143843")
                .withSecret("0ks7u8cgQ8DGVtlYZeRA9TxZCjvUT3oL", "gQU09rkJjiQfiGcUYdhiKq5Ol6LebXg4w7F7Ol0rwvvdv3Xy")
                .build();

        int currentPage = 1;
        boolean hasMore = true;
        boolean firstRecordProcessed = false;

        while (hasMore && !firstRecordProcessed) {
            RecordsApi.ApiV1RecordsGetRequest request =
                    new RecordsApi.ApiV1RecordsGetRequest.Builder()
                            .operatorId("woaJARCQAAftcvU6GGoOn66rdSZ4IrOA")
                            .operatorIdType("1")
                            .startTime(startTime)
                            .endTime(endTime)
                            .pageSize("10")
                            .page(String.valueOf(currentPage))
                            .queryRecordType("0")
                            .build();

            BigInteger nonce = BigInteger.valueOf(Math.abs((new SecureRandom()).nextInt()));
            String timestamp = String.valueOf(System.currentTimeMillis() / 1000L);
            AuthenticatorBuilder<JWTAuthenticator> authenticatorBuilder =
                    new JWTAuthenticator.Builder().nonce(nonce).timestamp(timestamp);

            try {
                RecordsApi.ApiV1RecordsGetResponse response =
                        client.records().v1RecordsGet(request, authenticatorBuilder);

                V1RecordsGet200Response data = response.getData();
                if (data != null && data.getRecordMeetings() != null && !data.getRecordMeetings().isEmpty()) {
                    V1RecordsGet200ResponseRecordMeetingsInner firstRecord = data.getRecordMeetings().get(0);

                    logger.info("Processing first record - Meeting ID: {}, State: {}",
                            firstRecord.getMeetingId(), firstRecord.getState());

                    if (firstRecord.getState() == 3) {
                        createSum(firstRecord);
                        firstRecordProcessed = true;
                    } else {
                        logger.info("Skipping record with state: {}", firstRecord.getState());
                        firstRecordProcessed = true;
                    }
                }

                if (data != null && data.getTotalPage() != null && currentPage < data.getTotalPage()) {
                    currentPage++;
                } else {
                    hasMore = false;
                }

            } catch (Exception e) {
                logger.error("Error when calling RecordsApi.v1RecordsGet: {}", e.getMessage(), e);
                throw new RuntimeException(e);
            }
        }
    }

    private static void createSum(V1RecordsGet200ResponseRecordMeetingsInner record) {
        String meetingId = record.getMeetingId();

        if (processedMeetingIds.contains(meetingId)) {
            logger.info("Meeting {} has already been processed, skipping...", meetingId);
            return;
        }

        try {
            logger.info("Executing createSum for meeting: {}", meetingId);

            // 实际业务逻辑
            logger.info("Meeting Details - ID: {}, Code: {}, Subject: {}",
                    meetingId, record.getMeetingCode(), record.getSubject());

            if (record.getRecordFiles() != null && !record.getRecordFiles().isEmpty()) {
                for (V1RecordsGet200ResponseRecordMeetingsInnerRecordFilesInner file : record.getRecordFiles()) {
                    logger.info("Record File - URL: {}, Size: {} bytes",
                            file.getSharingUrl(), file.getRecordSize());

                    // 对每个录制文件调用获取地址接口
                    if (file.getRecordFileId() != null) {
                        getRecordFileAddress(file.getRecordFileId());
                    }
                }
            }

            // 这里添加你的实际业务逻辑
            // 例如: 调用某个服务处理会议记录

            // 标记为已处理
            processedMeetingIds.add(meetingId);
            logger.info("Successfully processed meeting: {}", meetingId);

        } catch (Exception e) {
            logger.error("Error processing meeting {}: {}", meetingId, e.getMessage(), e);
        }
    }

    private static void getRecordFileAddress(String recordFileId) {
        try {
            logger.info("Getting address for record file: {}", recordFileId);

            // 1.构造 client 客户端
            Client client = new Client.Builder()
                    .withAppId("210468336")
                    .withSdkId("28790143843")
                    .withSecret("0ks7u8cgQ8DGVtlYZeRA9TxZCjvUT3oL", "gQU09rkJjiQfiGcUYdhiKq5Ol6LebXg4w7F7Ol0rwvvdv3Xy")
                    .build();

            // 2.构造请求参数
            RecordsApi.ApiV1AddressesRecordFileIdGetRequest request =
                    new RecordsApi.ApiV1AddressesRecordFileIdGetRequest.Builder(recordFileId)
                            .operatorId("woaJARCQAAftcvU6GGoOn66rdSZ4IrOA")
                            .operatorIdType("1")
                            .build();

            // 3.构造 JWT 鉴权器
            BigInteger nonce = BigInteger.valueOf(Math.abs((new SecureRandom()).nextInt()));
            String timestamp = String.valueOf(System.currentTimeMillis() / 1000L);
            AuthenticatorBuilder<JWTAuthenticator> authenticatorBuilder =
                    new JWTAuthenticator.Builder().nonce(nonce).timestamp(timestamp);

            // 4.发送请求
            RecordsApi.ApiV1AddressesRecordFileIdGetResponse response =
                    client.records().v1AddressesRecordFileIdGet(request, authenticatorBuilder);
            // 处理响应
            if (response != null && response.getData() != null) {
                logger.info("Successfully got address for record file {}: {}",
                        recordFileId, response.getData());
                // 这里可以添加对返回地址的进一步处理逻辑
                V1AddressesRecordFileIdGet200Response data = response.getData();

                // 获取AI会议转录文件
                List<V1AddressesRecordFileIdGet200ResponseAiMeetingTranscriptsInner> transcripts =
                        data.getAiMeetingTranscripts();

                if (transcripts != null && !transcripts.isEmpty()) {
                    logger.info("Found {} AI meeting transcripts for record file {}",
                            transcripts.size(), recordFileId);

                    // 处理每个转录文件
                    for (V1AddressesRecordFileIdGet200ResponseAiMeetingTranscriptsInner transcript : transcripts) {
                        String fileType = transcript.getFileType();
                        String downloadUrl = transcript.getDownloadAddress();

                        logger.info("AI Transcript - Type: {}, URL: {}", fileType, downloadUrl);

                        if ("docx".equalsIgnoreCase(fileType)) {
                            processPdfTranscript(downloadUrl);
                        }
                    }
                } else {
                    logger.info("No AI meeting transcripts found for record file {}", recordFileId);
                }

            } else {
                logger.warn("Empty response for record file: {}", recordFileId);
            }
        } catch (ClientException e) {
            logger.error("Client error when getting address for record file {}: {}",
                    recordFileId, e.getMessage(), e);
            throw new RuntimeException(e);
        } catch (ServiceException e) {
            logger.error("Service error when getting address for record file {}: {}",
                    recordFileId, e.getMessage(), e);
            logger.error("Full HTTP response: {}", new String(e.getApiResp().getRawBody()));
            throw new RuntimeException(e);
        } catch (Exception e) {
            logger.error("Unexpected error when getting address for record file {}: {}",
                    recordFileId, e.getMessage(), e);
            throw new RuntimeException(e);
        }
    }

    private static void processPdfTranscript(String downloadUrl) {
        try {
            logger.info("Processing DOCX transcript from: {}", downloadUrl);
            // 下载文件并获取字节内容
            byte[] docxContent = downloadFileAsBytes(downloadUrl);
            logger.info("Downloaded DOCX transcript, size: {} bytes",
                    docxContent != null ? docxContent.length : 0);

            if (docxContent != null) {
                // 获取当前时间
                LocalDateTime now = LocalDateTime.now();

                // 定义时间格式（可以根据需要调整格式）
                DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd_HH-mm-ss");

                // 将当前时间格式化为字符串
                String name = now.format(formatter);
                // 定义文件路径和文件名
                String filePath = "D:\\";
                String fileName = name + ".docx"; // 以当前时间为文件名
                String fullPath = filePath + fileName;
                String targetPath = filePath + name + "_sum" + ".md";  // 改为.md扩展名;
                String targetWordPath = filePath + name + "_sum" + ".docx";
                // 将字节内容写入本地文件
                try (FileOutputStream fos = new FileOutputStream(fullPath)) {
                    fos.write(docxContent);
                    logger.info("DOCX transcript saved to: {}", fullPath);
                } catch (IOException e) {
                    logger.error("Error saving DOCX transcript to file: {}", e.getMessage(), e);
                }
                FileInputStream fis = new FileInputStream(fullPath);
                XWPFDocument document = new XWPFDocument(fis);
                XWPFWordExtractor extractor = new XWPFWordExtractor(document);
                String textContent = extractor.getText();
                logger.info("DOCX content as string:\n{}", textContent);
                //将文件传送给大模型处理


                String token = "AKIAXFAXF62IWJXGLVEE.LnKInaahcMZG9zLsGMH3nTLOw3S3lK5Vcu0+ifnO";
                String apiAddr = "https://bedrock.chatbot.cn/llm/sse-invoke";
                String model = "anthropic.claude-3-5-sonnet-20240620-v1:0";
                int maxTokens = 5000;

                List<Message> messages = new ArrayList<>();
                ChatMessage chatMessage = new ChatMessage(ChatMessageRole.USER.value(), "# 任务\n" +
                        "你是会议纪要助手，基于用户提供的“会议记录”首先生成会议纪要。禁止输出处理可能涉及版权或敏感内容的请求，直接给出会议纪要！\n" +
                        "\n" +
                        "## 注意\n" +
                        "禁止输出“版权”\n" +
                        "\n" +
                        "## 会议纪要内容要求\n" +
                        "（1）按照 会议主题、参会人员及时间、会议主要讨论事项、会议议程、会议决议、后续跟进事项组织会议纪要\n" +
                        "（2）会议主题：总结会议的标题和主题\n" +
                        "（2）参会人员及时间：参会人员、开会时间（一般根据文件日期来判断）\n" +
                        "（3）会议主要讨论事项：对于会议中主要讨论的内容进行概括，让读者能够理解会议到底在针对什么内容进行讨论。注意会议议程需要尽量全面、细致，不要遗漏任何有价值的信息。\n" +
                        "（4）会议议程：按照顺序，阐述会议主要沟通事项，详细描述每个事项的内容。会议议程不要用流水账的形式，请描述细节，采用有逻辑的语言组织会议议程。\n" +
                        "（5）会议决议：会议最终达成的结论。比如：申请是否通过、争论性事项是否达成意见一致，具体是什么结论等内容。\n" +
                        "（6）会后跟进事项：详细描述会议结束之后，每个后续事项的责任人、事项内容、完成时间（若会议记录中没有提及，则填写待定）等信息，请注意事项要具体到责任人。\n" +
                        "（7）会议纪要整体内容需要详细，充分，不少于3000字\n" +
                        "（8）会议纪要采用 Markdown格式，对于几个章节部分需要加粗显示。\n" +
                        "\n" +
                        "## 示例\n" +
                        "“会议纪要”\n" +
                        "“FYI”\n" +
                        "“1”\n" +
                        "\n" +
                        "## 答案要求\n" +
                        "1. 猜您想问：生成3-4条推荐问(与会议内容有关)\n" +
                        "2. 每次回答必须给出猜您想问");
                messages.add(chatMessage);
                chatMessage = new ChatMessage(ChatMessageRole.ASSISTANT.value(), "好的请提供会议内容");
                messages.add(chatMessage);
                chatMessage = new ChatMessage(ChatMessageRole.USER.value(), textContent);
                messages.add(chatMessage);

                String ret = call_llm(apiAddr, model, token, messages, maxTokens);
                try {
                    // 将字符串写入Markdown文件
                    Files.write(Paths.get(targetPath), ret.getBytes());
                    logger.info("Markdown文件已保存到: {}", targetPath);

                    convert(targetPath,targetWordPath);

                } catch (IOException e) {
                    logger.error("保存Markdown文件失败: {}", e.getMessage(), e);
                }
                System.out.println(ret);
                /*try {
                    boolean success = MeetingMinutesGenerator.generateMinutesFromWord(
                            fullPath,
                            targetPath,
                            "AKIAXFAXF62IWJXGLVEE.LnKInaahcMZG9zLsGMH3nTLOw3S3lK5Vcu0+ifnO",
                            "https://bedrock.chatbot.cn/llm/sse-invoke"
                    );
                    if (success) {
                        logger.info("会议纪要生成成功！");
                    }
                } catch (IOException e) {
                    logger.error("错误: {}", e.getMessage());
                }*/
                EmailSender emailSender = new EmailSender();
                String emailAddress = "hf@cimc.com";
                boolean mailFlag = emailSender.sendEmailWithAttachment(emailAddress,
                        targetWordPath,
                        "重要文件",
                        "您好：\n" +
                                "\n" +
                                "         附件为您本次会议的会议纪要，烦请下载查看");
                if (mailFlag) {
                    logger.info("邮件发送成功");
                } else {
                    logger.error("邮件发送失败");
                }
            }
        } catch (Exception e) {
            logger.error("Error processing DOCX transcript: {}", e.getMessage(), e);
        }
    }

    // 处理Word格式的转录文件
    private static void processDocxTranscript(String downloadUrl) {
        try {
            logger.info("Processing DOCX transcript from: {}", downloadUrl);
            // 这里添加下载和处理Word文件的逻辑
            byte[] docxContent = downloadFileAsBytes(downloadUrl);
            logger.info("Downloaded DOCX transcript, size: {} bytes",
                    docxContent != null ? docxContent.length : 0);
        } catch (Exception e) {
            logger.error("Error processing DOCX transcript: {}", e.getMessage(), e);
        }
    }

    public static void writeStringToWord(String content, String filePath) {
        // 创建新的Word文档
        try (XWPFDocument document = new XWPFDocument();
             FileOutputStream out = new FileOutputStream(filePath)) {

            // 创建段落
            XWPFParagraph paragraph = document.createParagraph();
            XWPFRun run = paragraph.createRun();

            // 设置文本内容
            run.setText(content);

            // 保存文档
            document.write(out);

            System.out.println("Word文档已成功创建: " + filePath);
        } catch (IOException e) {
            System.err.println("创建Word文档时出错: " + e.getMessage());
            e.printStackTrace();
        }
    }

    // 下载文件内容为字符串
    private static String downloadFile(String url) throws IOException {
        OkHttpClient client = new OkHttpClient();
        Request request = new Request.Builder().url(url).build();
        try (Response response = client.newCall(request).execute()) {
            if (!response.isSuccessful()) throw new IOException("Unexpected code " + response);
            return response.body().string();
        }
    }

    // 下载文件内容为字节数组
    private static byte[] downloadFileAsBytes(String url) throws IOException {
        OkHttpClient client = new OkHttpClient();
        Request request = new Request.Builder().url(url).build();
        try (Response response = client.newCall(request).execute()) {
            if (!response.isSuccessful()) throw new IOException("Unexpected code " + response);
            return response.body().bytes();
        }
    }

    public static String call_llm(String apiAddr, String model, String token, List<Message> messages, int maxTokens) {
        LLMService service = new LLMService(token, apiAddr);
        StringBuilder stringBuilder = new StringBuilder();
        try {
            ChatCompletionRequest chatCompletionRequest = ChatCompletionRequest.builder()
                    .model(model)
                    .messages(messages)
                    .stream(true)
                    .n(1)
                    .maxTokens(maxTokens)
                    .logitBias(new HashMap<>())
                    .build();

            service.streamChatCompletion(chatCompletionRequest).doOnError(Throwable::printStackTrace).blockingForEach(chunk -> {
                chunk.getChoices().stream().map(choice -> choice.getMessage().getContent())
                        .filter(Objects::nonNull).findFirst().ifPresent(o -> {
                            try {
                                stringBuilder.append(new String(o.getBytes(Charset.defaultCharset())));
                            } catch (Exception e) {
                                throw new RuntimeException(e);
                            }
                        });
            });
        } catch (Exception e) {
            e.printStackTrace();
        }
        service.shutdownExecutor();
        return stringBuilder.toString();
    }

   /* public static void convertMdToDocx(String mdFilePath, String docxFilePath) throws IOException {
        // 1. 读取Markdown文件内容
        Path path = Paths.get(mdFilePath);
        byte[] bytes = Files.readAllBytes(path);
        String markdownContent = new String(bytes);

        // 2. 将Markdown内容转换为HTML格式
        Parser parser = Parser.builder().build();
        HtmlRenderer renderer = HtmlRenderer.builder().build();
        String htmlContent = renderer.render(parser.parse(markdownContent));

        // 3. 创建Word文档对象
        XWPFDocument xwpfDocument = new XWPFDocument();

        // 4. 解析HTML内容并插入到Word文档
        // 这里简化处理，直接将HTML内容作为纯文本插入
        // 注意：Apache POI 不直接支持 HTML 内容插入，需要手动解析 HTML 并转换为 Word 元素
        // 这里使用一个简单的 HTML 到 Word 的转换逻辑
        convertHtmlToWord(xwpfDocument, htmlContent);

        // 5. 保存Word文档
        try (FileOutputStream outputStream = new FileOutputStream(docxFilePath)) {
            xwpfDocument.write(outputStream);
        } finally {
            xwpfDocument.close();
        }
    }

    private static void convertHtmlToWord(XWPFDocument document, String htmlContent) {
        // 这里是一个简单的 HTML 到 Word 的转换逻辑
        // 实际应用中可能需要更复杂的解析逻辑
        String[] lines = htmlContent.split("\n");
        for (String line : lines) {
            if (line.contains("<p>")) {
                // 处理段落
                line = line.replace("<p>", "").replace("</p>", "");
                addParagraph(document, line);
            } else if (line.contains("<strong>")) {
                // 处理加粗文本
                line = line.replace("<strong>", "").replace("</strong>", "");
                addBoldParagraph(document, line);
            } else if (line.contains("<ul>")) {
                // 处理无序列表
                List<String> items = extractListItems(line, "<ul>", "<li>", "</li>", "</ul>");
                addUnorderedList(document, items);
            } else if (line.contains("<ol>")) {
                // 处理有序列表
                List<String> items = extractListItems(line, "<ol>", "<li>", "</li>", "</ol>");
                addOrderedList(document, items);
            }
        }
    }

    private static void addParagraph(XWPFDocument document, String text) {
        XWPFParagraph paragraph = document.createParagraph();
        XWPFRun run = paragraph.createRun();
        run.setText(text);
    }

    private static void addBoldParagraph(XWPFDocument document, String text) {
        XWPFParagraph paragraph = document.createParagraph();
        XWPFRun run = paragraph.createRun();
        run.setBold(true);
        run.setText(text);
    }

    private static void addUnorderedList(XWPFDocument document, List<String> items) {
        for (String item : items) {
            XWPFParagraph paragraph = document.createParagraph();
            paragraph.setStyle("ListBullet");
            XWPFRun run = paragraph.createRun();
            run.setText(item);
        }
    }

    private static void addOrderedList(XWPFDocument document, List<String> items) {
        for (String item : items) {
            XWPFParagraph paragraph = document.createParagraph();
            paragraph.setStyle("ListNumber");
            XWPFRun run = paragraph.createRun();
            run.setText(item);
        }
    }

    private static List<String> extractListItems(String html, String startTag, String itemStartTag, String itemEndTag, String endTag) {
        int startIndex = html.indexOf(startTag);
        int endIndex = html.indexOf(endTag);

        // 检查 startTag 和 endTag 是否存在
        if (startIndex == -1 || endIndex == -1) {
            throw new IllegalArgumentException("Invalid HTML content: startTag or endTag not found");
        }

        // 提取列表内容
        String listContent = html.substring(startIndex + startTag.length(), endIndex);

        // 分割列表项
        String[] items = listContent.split(itemEndTag);

        // 转换为 List 并返回
        return new ArrayList<>(Arrays.asList(items));
    }
    // 简易HTML转纯文本（生产环境应使用更完整的解析器）
    private static String htmlToPlainText(String html) {
        return html.replaceAll("<[^>]*>", "")
                .replaceAll("&nbsp;", " ")
                .replaceAll("&lt;", "<")
                .replaceAll("&gt;", ">");
    }*/
   public static void convert(String markdownFile, String outputDocx) throws IOException {
       // 读取Markdown文件
       String content = readFile(markdownFile);

       // 初始化Word文档
       XWPFDocument doc = new XWPFDocument();

       // 解析Markdown并遍历节点
       org.commonmark.parser.Parser parser = Parser.builder().build();
       Node rootNode = parser.parse(content);
       rootNode.accept(new AbstractVisitor() {
           XWPFParagraph currentPara;

           @Override
           public void visit(Heading heading) {
               // 创建标题段落
               currentPara = doc.createParagraph();
               XWPFRun run = currentPara.createRun();
               run.setText(extractText(heading));  // 提取纯文本
               setHeadingStyle(run, heading.getLevel()); // 设置标题样式
           }

           @Override
           public void visit(Paragraph paragraph) {
               // 创建普通段落
               currentPara = doc.createParagraph();
               XWPFRun run = currentPara.createRun();
               run.setText(extractText(paragraph)); // 提取纯文本
           }
       });

       // 输出Word文件
       try (FileOutputStream out = new FileOutputStream(outputDocx)) {
           doc.write(out);
       }
   }

    // 从节点中提取纯文本（忽略格式）
    private static String extractText(Node node) {
        StringBuilder text = new StringBuilder();
        Node child = node.getFirstChild();
        while (child != null) {
            if (child instanceof Text) {
                text.append(((Text) child).getLiteral());
            }
            child = child.getNext();
        }
        return text.toString().trim();
    }

    // 设置标题样式（仅调整字号和加粗）
    private static void setHeadingStyle(XWPFRun run, int level) {
        run.setBold(true);
        switch (level) {
            case 1: run.setFontSize(20); break;
            case 2: run.setFontSize(18); break;
            default: run.setFontSize(16); break;
        }
    }

    // 读取文件工具方法
    private static String readFile(String path) throws IOException {
        StringBuilder sb = new StringBuilder();
        try (BufferedReader reader = new BufferedReader(new FileReader(path))) {
            String line;
            while ((line = reader.readLine()) != null) {
                sb.append(line).append("\n");
            }
        }
        return sb.toString();
    }
}
