/*
package com.cmeeting.job;

import com.cmeeting.pojo.MeetingInfo;
import com.tencentcloudapi.wemeet.Client;
import com.tencentcloudapi.wemeet.service.meetings.api.MeetingsApi;
import com.tencentcloudapi.wemeet.service.meetings.model.V1HistoryMeetingsUseridGet200ResponseMeetingInfoListInner;
import com.tencentcloudapi.wemeet.service.records.api.RecordsApi;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.math.BigInteger;
import java.security.SecureRandom;
import java.time.LocalDateTime;
import java.time.ZoneId;
import java.time.format.DateTimeFormatter;
import java.util.*;


import com.tencentcloudapi.wemeet.core.authenticator.AuthenticatorBuilder;
import com.tencentcloudapi.wemeet.core.authenticator.JWTAuthenticator;
import com.tencentcloudapi.wemeet.core.exception.ClientException;
import com.tencentcloudapi.wemeet.core.exception.ServiceException;

@Component
public class CmeetingJob2 {
    private static final Logger logger = LoggerFactory.getLogger(CmeetingJob2.class);

    private static final DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");

    // 每2分钟执行一次
    @Scheduled(fixedRate = 2 * 60 * 1000) // 毫秒单位
    public void execute() {

        // 获取当前时间
        LocalDateTime now = LocalDateTime.now();
        // 获取前两分钟的时间
        LocalDateTime twoMinutesAgo = now.minusMinutes(2);
        // 转换为时间戳（毫秒级）并转为String
        String nowTimestamp = String.valueOf(now.atZone(ZoneId.systemDefault()).toInstant().toEpochMilli());
        String twoMinutesAgoTimestamp = String.valueOf(twoMinutesAgo.atZone(ZoneId.systemDefault()).toInstant().toEpochMilli());
        logger.info("当前时间: {} | 时间戳: {}", now.format(formatter), nowTimestamp);
        logger.info("前两分钟: {} | 时间戳: {}", twoMinutesAgo.format(formatter), twoMinutesAgoTimestamp);
        logger.info("----------------------------------");
        dojob(twoMinutesAgoTimestamp, nowTimestamp);
    }

    public static void dojob(String startTime, String endTime) {
        // 1.构造 client 客户端(jwt 鉴权需要配置 appId sdkId secretID 和 secretKey)
        Client client = new Client.Builder()
                .withAppId("211153201").withSdkId("28370276340")
                .withSecret("BKOMDZVbvh0iT7k6UHsSizAWBCOVDtT6", "3Y1j0mzNp7KChKFJGyaEnZHLobFoAQ8eLwfaMx8nLbtXAerO")
                .build();
        String userid = "woaJARCQAAJU1EsO73Ww5rn8YHMW6iYA";//被查询人的userid
        // 2.构造请求参数
        MeetingsApi.ApiV1HistoryMeetingsUseridGetRequest request =
                new MeetingsApi.ApiV1HistoryMeetingsUseridGetRequest.Builder(userid)
                        .pageSize("1")
                        .page("1")
                        .startTime(startTime)
                        .endTime(endTime)
                        .build();
        // 3.构造 JWT 鉴权器
        // 随机数
        BigInteger nonce = BigInteger.valueOf(Math.abs((new SecureRandom()).nextInt()));
        // 当前时间戳
        String timestamp = String.valueOf(System.currentTimeMillis() / 1000L);
        AuthenticatorBuilder<JWTAuthenticator> authenticatorBuilder =
                new JWTAuthenticator.Builder().nonce(nonce).timestamp(timestamp);
        try {
            MeetingsApi.ApiV1HistoryMeetingsUseridGetResponse response =
                    client.meetings().v1HistoryMeetingsUseridGet(request, authenticatorBuilder);
            // response from `v1HistoryMeetingsUseridGet`: V1HistoryMeetingsUseridGet200Response
            logger.info("从查询某个用户结束会议列表接口获取的响应结果：\n响应头信息: {}\n响应体数据: {}",
                    response.getHeader(),
                    response.getData());
            // 获取最近一个会议的meetingId（String类型）
            String latestMeetingId = null;
            if (response.getData() != null &&
                    response.getData().getMeetingInfoList() != null &&
                    !response.getData().getMeetingInfoList().isEmpty()) {

                // 获取会议列表（假设是按时间倒序排列）
                List<V1HistoryMeetingsUseridGet200ResponseMeetingInfoListInner> meetingInfoList = response.getData().getMeetingInfoList();
                List<MeetingInfo> meetingInfos = new ArrayList<>();
                // 转换处理
                if (meetingInfoList != null) {
                    for (V1HistoryMeetingsUseridGet200ResponseMeetingInfoListInner source : meetingInfoList) {
                        MeetingInfo target = new MeetingInfo();
                        target.setSubject(source.getSubject());
                        target.setMeetingId(source.getMeetingId());
                        target.setMeetingCode(source.getMeetingCode());
                        target.setStartTime(source.getStartTime());
                        target.setEndTime(source.getEndTime());
                        meetingInfos.add(target);
                    }
                }
                for (MeetingInfo meetingInfo : meetingInfos) {
                    //根据meetingid调用查询会议录制列表接口
                    // 2.构造请求参数
                    String meetingId = meetingInfo.getMeetingId();
                    String startTime1 = String.valueOf(meetingInfo.getStartTime());
                    String endTime1 = String.valueOf(meetingInfo.getEndTime());

                    RecordsApi.ApiV1RecordsGetRequest request2 =
                            new RecordsApi.ApiV1RecordsGetRequest.Builder()
                                    .operatorId("woaJARCQAAJU1EsO73Ww5rn8YHMW6iYA")
                                    .operatorIdType("1")
                                    .meetingId(meetingId)
                                    .startTime(startTime1)
                                    .endTime(endTime1)
                                    .build();
                    // 3.构造 JWT 鉴权器
                    // 随机数
                    BigInteger nonce2 = BigInteger.valueOf(Math.abs((new SecureRandom()).nextInt()));
                    // 当前时间戳
                    String timestamp2 = String.valueOf(System.currentTimeMillis() / 1000L);
                    AuthenticatorBuilder<JWTAuthenticator> authenticatorBuilder2 =
                            new JWTAuthenticator.Builder().nonce(nonce2).timestamp(timestamp2);
                    try {
                        RecordsApi.ApiV1RecordsGetResponse response2 =
                                client.records().v1RecordsGet(request2, authenticatorBuilder2);
                        logger.info("查询会议录制列表接口响应结果：\n响应头信息: {}\n响应体数据: {}",
                                response2.getHeader(),
                                response2.getData());

                        // 1. 空值安全校验
                        if (response2 == null || response2.getData() == null) {
                            logger.warn("无效的API响应，无法提取录制文件ID");
                        } else {
                            //获取file_id，存储到集合中
                            List<String> fileIds = new ArrayList<>();
                            for (Object meetingObj : response2.getData().getRecordMeetings()) {
                                if (meetingObj instanceof Map) {
                                    Map<?, ?> meeting = (Map<?, ?>) meetingObj;
                                    Object recordFilesObj = meeting.get("record_files");

                                    if (recordFilesObj instanceof List) {
                                        for (Object fileObj : (List<?>) recordFilesObj) {
                                            if (fileObj instanceof Map) {
                                                Map<?, ?> file = (Map<?, ?>) fileObj;
                                                Object fileIdObj = file.get("record_file_id");

                                                // 将record_file_id转为String并添加到集合
                                                if (fileIdObj != null) {
                                                    fileIds.add(String.valueOf(fileIdObj));
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                            //调用查询录制转写详情接口获取当前record_file_id的多个下载地址

                        }

                    } catch (ClientException e) {
                        logger.error("调用查询会议录制列表接口时发生错误", e);
                        throw new RuntimeException(e);
                    } catch (ServiceException e) {
                        logger.error("调用查询会议录制列表接口时发生异常", e);
                        logger.error("完整HTTP错误响应: {}", new String(e.getApiResp().getRawBody()));
                        throw new RuntimeException(e);
                    }
                }

                logger.info("成功获取会议的信息: {}", meetingInfoList);
            } else {
                logger.warn("未获取到任何会议信息");
            }

        } catch (ClientException e) {
            logger.error("调用查询某个用户结束会议列表接口时发生错误", e);
            throw new RuntimeException(e);

        } catch (ServiceException e) {
            logger.error("调用查询某个用户结束会议列表接口时发生异常", e);
            logger.error("完整HTTP错误响应: {}", new String(e.getApiResp().getRawBody()));
            throw new RuntimeException(e);
        }

        */
/**
         * 调用查询会议录制列表接口，获取录制文件id
         *//*

        // 2.构造请求参数
        RecordsApi.ApiV1RecordsGetRequest requestGetFileId =
                new RecordsApi.ApiV1RecordsGetRequest.Builder()
                        .operatorId("woaJARCQAAJU1EsO73Ww5rn8YHMW6iYA")
                        .operatorIdType("1")
                        .userid("")
                        .meetingId("9672653404723270528")
                        .meetingCode("")
                        .startTime("1744795527")
                        .endTime("1744799127")
                        .pageSize("")
                        .page("")
                        .mediaSetType("")
                        .queryRecordType("1")
                        .build();
        // 3.构造 JWT 鉴权器
        // 随机数
        BigInteger nonce2 = BigInteger.valueOf(Math.abs((new SecureRandom()).nextInt()));
        // 当前时间戳
        String timestamp2 = String.valueOf(System.currentTimeMillis() / 1000L);
        AuthenticatorBuilder<JWTAuthenticator> authenticatorBuilder2 =
                new JWTAuthenticator.Builder().nonce(nonce2).timestamp(timestamp2);
        try {
            RecordsApi.ApiV1RecordsGetResponse response2 =
                    client.records().v1RecordsGet(requestGetFileId, authenticatorBuilder2);
            logger.info("获取会议录制列表接口响应结果：\n响应头: {}\n响应体: {}",
                    response2.getHeader(),
                    response2.getData());
        } catch (ClientException e) {
            logger.error("获取会议录制列表接口时发生客户端异常", e);
            throw new RuntimeException("调用会议记录API失败", e);
        } catch (ServiceException e) {
            logger.error("调用获取会议录制列表接口时发生服务端异常", e);
            if (e.getApiResp() != null) {
                logger.error("完整错误响应内容: {}", new String(e.getApiResp().getRawBody()));
            }
            throw new RuntimeException("获取会议记录服务异常", e);
        }

    }

}
*/
